
import jahuwaldt.jatex.AppGUI;
import jahuwaldt.jatex.AppPreferences;
import jahuwaldt.jatex.MainWindow;
import jahuwaldt.swing.AppUtilities;
import jahuwaldt.swing.MDIApplication;
import jahuwaldt.swing.MainApp;
import jahuwaldt.swing.Preferences;
import java.awt.Frame;
import java.util.Locale;
import java.util.ResourceBundle;
import javax.swing.SwingUtilities;

/**
 * Application to use LaTeX to parse a formula into an image file.
 *
 * <p> Modified by: Joseph A. Huwaldt </p>
 *
 * @author Joseph A. Huwaldt, Date: May 10, 2013
 * @version December 16, 2023
 */
public class JaTeX implements MainApp {

    /**
     * The resource bundle containing the string resources for this application. Resource
     * bundles are useful for localizing applications. New localities (languages) can be
     * added by adding properties files only -- no code modifications.
     */
    public static final ResourceBundle RESBUNDLE = ResourceBundle.getBundle("appStrings", Locale.getDefault());

    //  A reference to our GUI application instance.
    private final MDIApplication guiApp;

    /**
     * The user preferences for this program.
     */
    private final AppPreferences prefs;

    /**
     * Entry point for this application. This is where it starts up from.
     *
     * @param args Command line arguments for the program (ignored).
     */
    public static void main(String[] args) {
        // All code that creates or interacts with Swing components must run on the
        // event dispatch thread.
        SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
                try {
                    // Create an instance of our application.
                    new JaTeX();

                } catch (Throwable e) {
                    e.printStackTrace();
                    AppUtilities.showException(null, RESBUNDLE.getString("unexpectedTitle"),
                            RESBUNDLE.getString("unexpectedMsg"), e);
                    System.exit(0);
                }
            }
        });

    }

    /**
     * Constructor for our application that displays the GUI.
     *
     * @throws java.lang.Exception if there is any problem getting started.
     */
    public JaTeX() throws Exception {

        //  Create the MDIApplication.
        guiApp = new AppGUI(RESBUNDLE);
        
        //  Load in the user preferences.
        prefs = new AppPreferences();
        MDIApplication.setPreferences(prefs);

        // Check the configuration.
        boolean setPrefs = prefs.hasLatex();

        // Create an instance of an application window to get the program rolling.
        String title = RESBUNDLE.getString("appName") + ", "
                + RESBUNDLE.getString("version") + " "
                + RESBUNDLE.getString("appVersion");
        Frame window = new MainWindow(title);
        window.setVisible(true);
        MDIApplication.addWindow(window);

        //  Display the preferences dialog if necessary.
        if (setPrefs) {
            prefs.showPreferenceDialog();
        }
    }

    //-----------------------------------------------------------------------------------
    /**
     * Returns the resource bundle stored with this application. If no resource bundle has
     * been stored, then null is returned.
     *
     * @return The resource bundle used by this program.
     */
    @Override
    public final ResourceBundle getResourceBundle() {
        return RESBUNDLE;
    }

    /**
     * Return a reference to this program's GUI application or <code>null</code> if we are
     * running in batch mode.
     *
     * @return The GUI application instance used by this program.
     */
    @Override
    public final MDIApplication getGUIApplication() {
        return guiApp;
    }

    /**
     * Return a reference to the user preferences for this application.
     *
     * @return The preferences used by this program.
     */
    @Override
    public final Preferences getPreferences() {
        return prefs;
    }

}
